<?php

namespace Drupal\synimport\Service;

use Drupal\Core\Config\FileStorage;

/**
 * Taxomy import class.
 *
 * @internal
 *   For internal usage by the Commerce synimport module.
 */
class Taxonomy {
  /**
   * Logger variable.
   *
   * @var Logger
   */
  protected $log;

  /**
   * CreateEntity Service variable.
   *
   * @var CreateEntity
   */
  protected $createEntity;

  /**
   * Service constructor.
   *
   * @param Logger $log
   * @param CreateEntity $createEntity
   */
  public function __construct(Logger $log, CreateEntity $createEntity) {
    $this->log = $log;
    $this->createEntity = $createEntity;
  }

  /**
   * Import Taxonomy.
   */
  public function import(string $directory) {
    $sourceTaxonomy = new FileStorage($directory);
    foreach ($sourceTaxonomy->listAll() as $file) {
      $term_array = $sourceTaxonomy->read($file);
      $vocabulary_array = $term_array['vocabulary'];
      if (!empty($vocabulary_array)) {
        if (!$this->checkVocabularyExistence($vocabulary_array['vid'])) {
          $this->createEntity->create($vocabulary_array, 'taxonomy_vocabulary');
        }
      }
      $term = $this->createEntity->create($term_array, 'taxonomy_term');
    }
  }

  /**
   * Checks vocabulary for existence.
   */
  private function checkVocabularyExistence(string $vid) : bool {
    $storage = \Drupal::entityTypeManager()->getStorage('taxonomy_vocabulary');
    if (empty($storage->load($vid))) {
      return FALSE;
    }
    return TRUE;
  }

}
